Reads and parses the header of a test file as available through the ASTER reflectance database. The Name field is retrieved and copied to attribute "what.measured". The header of the file is preserved as a comment.
read_ASTER_txt(file, date = NULL, geocode = NULL, label = NULL,
tz = NULL, locale = readr::default_locale(), npixels = 2048)character string
a POSIXct object to use to set the "when.measured"
attribute. If NULL, the default, the date is extracted from the
file header.
A data frame with columns lon and lat used to
set attribute "where.measured".
character string, but if NULL the value of file is
used, and if NA the "what.measured" attribute is not set.
character Ignored.
The locale controls defaults that vary from place to place. The
default locale is US-centric (like R), but you can use
locale to create your own locale that controls things
like the default time zone, encoding, decimal mark, big mark, and day/month
names.
integer Number of pixels in spectral data.
A raw_spct object.
https://www.r4photobiology.info https://speclib.jpl.nasa.gov/ Baldridge, A.; Hook, S.; Grove, C. & Rivera, G. (2009) The ASTER spectral library version 2.0. Remote Sensing of Environment. 113, 711-715