Reads and parses the header of a processed data file as output by the program Avaspec and then imports wavelength and spectral irradiance values. The file header has little useful metadata information.
read_avaspec_csv(file, date = NULL, geocode = NULL, label = NULL,
tz = NULL, locale = readr::default_locale())read_avaspec_xls(path, date = NULL, geocode = NULL, label = NULL,
tz = NULL, locale = readr::default_locale())
character string
a POSIXct object to use to set the "when.measured"
attribute. If NULL, the default, the date is extracted from the
file header.
A data frame with columns lon and lat used to
set attribute "where.measured".
character string, but if NULL the value of file is
used, and if NA the "what.measured" attribute is not set.
character Time zone used for interpreting times saved in the file header.
The locale controls defaults that vary from place to place. The
default locale is US-centric (like R), but you can use
locale to create your own locale that controls things
like the default time zone, encoding, decimal mark, big mark, and day/month
names.
Path to the xls/xlsx file
A source_spct object.