read_csi_dat(file, geocode = NULL, label = NULL, data_skip = 0, n_max = Inf, locale = readr::default_locale())lon and lat.NULL the value of file is
used, and if NA the "what.measured" attribute is not set.locale to create your own locale that controls things
like the default time zone, encoding, decimal mark, big mark, and day/month
names.read_csi_dat() returns a tibble::tibble object.