date.f.
read_fmi_cum(file, date = NULL, geocode = NULL, label = NULL, tz = NULL, locale = readr::default_locale(), .skip = 3, .n_max = -1, .date.f = lubridate::ymd)
read_m_fmi_cum(files, date = NULL, geocode = NULL, label = NULL, tz = NULL, .skip = 3, .n_max = -1, .date.f = lubridate::ymd)POSIXct object, but if NULL the date stored in
file is used, and if NA no date variable is addedlon and lat.NULL the value of file is
used, and if NA the "what.measured" attribute is not set.locale to create your own locale that controls things
like the default time zone, encoding, decimal mark, big mark, and day/month
names.POSIXct object.file.read_fmi_cum() returns a source_spct object with
time.unit attribute set to "day" and when.measured
attribute set to the date-time extracted from the file name.read_m_fmi_cum returns a collection of source_mspct.