Reads and parses the header of processed data text files output by Jaz instruments extracting the spectral data from the body of the file and the metadata, including time and date of measurement from the header. Jaz modular spectrometers are manufactured by Ocean Optics, Dunedin, Florida, USA.
read_oo_jazirrad(file, date = NULL, geocode = NULL, label = NULL,
tz = NULL, locale = readr::default_locale())read_oo_jazpc(file, qty.in = "Tpc", Tfr.type = c("total", "internal"),
Rfr.type = c("total", "specular"), date = NULL, geocode = NULL,
label = NULL, tz = NULL, locale = readr::default_locale())
read_oo_jazdata(file, date = NULL, geocode = NULL, label = NULL,
tz = NULL, locale = readr::default_locale())
character string.
a POSIXct object to use to set the "when.measured"
attribute. If NULL, the default, the date is extracted from the
file header.
A data frame with columns lon and lat used to
set attribute "where.measured".
character string, but if NULL the value of file is
used, and if NA the "what.measured" attribute is not set.
character Time zone used for interpreting times saved in the file header.
The locale controls defaults that vary from place to place. The
default locale is US-centric (like R), but you can use
locale to create your own locale that controls things
like the default time zone, encoding, decimal mark, big mark, and day/month
names.
character string, one of "Tpc" (spectral transmittance, %), "A" (spectral absorbance), or "Rpc" (spectral reflectance, %).
character string, either "total" or "internal".
character string, either "total" or "specular".
A source_spct object, a filter_spct object, a reflector_spct object or a raw_spct object.
Function read_oo_jazirrad can read processed irradiance
output files. Function read_oo_jazpc can read processed transmittance
and reflectance output files (expressed as %s). Function
read_oo_jazdata can read raw-counts data.