Reads and parses the header of a raw data file as output by the server running on a Raspberry Pi board to extract the whole header remark field. The time field is retrieved and decoded.
read_oo_pidata(file, date = NULL, geocode = NULL, label = NULL,
tz = NULL, locale = readr::default_locale(), npixels = 2048,
spectrometer.sn = "FLMS00673")character string
a POSIXct object to use to set the "when.measured"
attribute. If NULL, the default, the date is set to the file
modification date.
A data frame with columns lon and lat used to
set attribute "where.measured".
character string, but if NULL the value of file is
used, and if NA the "what.measured" attribute is not set.
character Time zone is not saved to the file.
The locale controls defaults that vary from place to place. The
default locale is US-centric (like R), but you can use
locale to create your own locale that controls things
like the default time zone, encoding, decimal mark, big mark, and day/month
names.
integer Number of pixels in spectral data.
character The serial number of the spectrometer needs to be supplied by the user as it is not included in the file header.
A raw_spct object.
https://www.r4photobiology.info https://oceanoptics.com/ https://www.raspberrypi.org/