Reads and parses the header of a processed data file as output by SpectraSuite to extract the whole header remark field. The time field is retrieved and decoded.
read_oo_ssirrad(file, date = NULL, geocode = NULL, label = NULL,
tz = NULL, locale = readr::default_locale())read_oo_ssdata(file, date = NULL, geocode = NULL, label = NULL,
tz = NULL, locale = readr::default_locale())
character string
a POSIXct object to use to set the "when.measured"
attribute. If NULL, the default, the date is extracted from the
file header.
A data frame with columns lon and lat used to
set attribute "where.measured".
character string, but if NULL the value of file is
used, and if NA the "what.measured" attribute is not set.
character Time zone is by default read from the file.
The locale controls defaults that vary from place to place. The
default locale is US-centric (like R), but you can use
locale to create your own locale that controls things
like the default time zone, encoding, decimal mark, big mark, and day/month
names.
A source_spct object.
A raw_spct object.