Reads and parses the header of a text file output by the TUV program to extract the header and spectral data. The time field is converted to a date.
read_tuv_usrout(file, date = lubridate::today(), geocode = NULL,
label = NULL, tz = NULL, locale = readr::default_locale())character string
a POSIXct object, but if NULL the date stored in
file is used, and if NA no date variable is added
A data frame with columns lon and lat.
character string, but if NULL the value of file is
used, and if NA the "what.measured" attribute is not set.
character Time zone is by default read from the file.
The locale controls defaults that vary from place to place. The
default locale is US-centric (like R), but you can use
locale to create your own locale that controls things
like the default time zone, encoding, decimal mark, big mark, and day/month
names.
a source_spct object obtained by 'melting' the TUV file, and adding
a factor spct.idx, and variables zenith.angle and
date.
http://www.r4photobiology.info https://www2.acom.ucar.edu/modeling/tuv-download