Read and parse a text file output by libRadtran's uvspec routine for a solar spectrum simulation. The output of uvspec depends among other things on the solver used. We define a family of functions, each function for a different solver.
read_uvspec_disort(file, date = NULL, geocode = NULL, label = NULL,
tz = NULL, locale = readr::default_locale(), multiplier = 0.001,
qty = "irradiance")character string
a POSIXct object, but if NULL the date stored in
file is used, and if NA no date variable is added
A data frame with columns lon and lat.
character string, but if NULL the value of file is
used, and if NA the "what.measured" attribute is not set.
character Time zone is by default read from the file.
The locale controls defaults that vary from place to place. The
default locale is US-centric (like R), but you can use
locale to create your own locale that controls things
like the default time zone, encoding, decimal mark, big mark, and day/month
names.
numeric A multiplier for conversion into W m-2 nm-1, as the units of expression of the output from "uvspec" depend on the units in which the extraterrestrial solar spectrum data is expressed.
character "uvspec" returns both irradiance and intensity with solver "disort".
A source_spct object.